@@ -1,6 +1,6 @@
 package RT::Extension::QuickDelete;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use warnings;
 use strict;
@@ -18,6 +18,10 @@ RT::Extension::QuickDelete - Adds a "quick delete" button to RT's standard ticke
  make install
  make initdb
 
+ Add RT::Extension::QuickDelete to your existin @Plugins line, or create a new @Plugins line:
+
+ Set(@Plugins, qw(RT::Extension::QuickDelete));
+
  # If you're using RT 3.6.0 or RT 3.6.1, copy etc/3.6.1/ShowSearch to /opt/rt3/share/html/Elements/ShowSearch
  # (This changed file is already included in RT 3.6.2)
  
@@ -37,12 +41,11 @@ RT::Extension::QuickDelete - Adds a "quick delete" button to RT's standard ticke
    '<small>__CreatedRelative__</small>',
    '<small>__ToldRelative__</small>',
    '<small>__LastUpdatedRelative__</small>',
-   '<small>__TimeLeft__</small>'}); 
-
-
-
-
+   '<small>__TimeLeft__</small>',
+   '__BLANK__/TITLE:NBSP'});
 
+On RT 4, this extension will not provide a Quick Delete link from the Ticket Display pages.  You can add one
+using the Lifecycles functionality.
 
 =head1 AUTHOR
 
@@ -51,7 +54,7 @@ Jesse Vincent  C<< <jesse@bestpractical.com> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2007, Best Practical Solutions, LLC.  All rights reserved.
+Copyright (c) 2007-2011, Best Practical Solutions, LLC.  All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
